import { defineStore } from 'pinia';
import { AxiosWrapper } from '@/util/axios-wrapper';
import type { IQueryType, IQueryResult, IQueryParams } from '@/util/types.util';
import { get } from 'lodash';
const url = '/notice';
const axios = new AxiosWrapper();

export const NoticeStore = defineStore('notice', () => {
  const query = async ({ skip = 0, limit = undefined, ...info }: IQueryParams = {}): Promise<IQueryResult> => {
    let cond: IQueryType = {};
    if (skip) cond.skip = skip;
    if (limit) cond.limit = limit;
    cond = { ...cond, ...info };
    const res = await axios.$get(`${url}`, cond);
    return res;
  };
  const fetch = async (payload: any): Promise<IQueryResult> => {
    const res = await axios.$get(`${url}/${payload}`);
    return res;
  };
  const create = async (payload: any): Promise<IQueryResult> => {
    const res = await axios.$post(`${url}`, payload);
    return res;
  };
  const update = async (payload: any): Promise<IQueryResult> => {
    const id = get(payload, 'id', get(payload, '_id'));
    const res = await axios.$post(`${url}/${id}`, payload);
    return res;
  };
  const del = async (payload: any): Promise<IQueryResult> => {
    const res = await axios.$delete(`${url}/${payload}`);
    return res;
  };
  return {
    query,
    fetch,
    create,
    update,
    del
  };
});
