import type { Ref } from 'vue';
import { ref, reactive } from 'vue';
import type { FormInstance, FormRules } from 'element-plus';
import { ElMessage } from 'element-plus';
import router from '@/router';
// 接口
import { LoginStore } from '@/stores/login';
import type { IQueryResult } from '@/util/types.util';
const loginStore = LoginStore();


// 表单
/**
 * 表单对象
 */
const formRef = ref<FormInstance>();
/**
 * 表单model
 */
const form: Ref<any> = ref({ type: 'SelfUser' });
/**
 * 输入规则
 */
const rules = reactive<FormRules>({
  account: [{ required: true, message: '请输入登录账号', trigger: 'blur' }],
  password: [{ required: true, message: '请输入账号密码', trigger: 'blur' }]
});

/**
 * 提交登录
 */
const toSave = async (formEl: any) => {
  if (!formEl) return;
  await formEl.validate((valid: any) => {
    if (valid) {
      toLogin(form.value);
    } else {
      console.log('error submit!');
    }
  });
};
const toLogin = async (data: any) => {
  const res: IQueryResult = await loginStore.login(data);
  if (res.errcode == '0') {
    ElMessage({ message: `登录成功`, type: 'success' });
    localStorage.setItem('token', `${res.data}`);
    // 路由
    router.push({ path: '/homeIndex' });
  } else {
    ElMessage({ message: `${res.errmsg}`, type: 'error' });
  }
};
export { toSave, formRef, form, rules };
